.. title:: Home

.. meta::
   :description: A modern, easy to use, Python ≥3.8 library for interacting with OBDII devices.
   :keywords: py-obdii, py-obd2, obdii, obd2
   :robots: index, follow

.. include:: ../../.github/README.rst
   :parser: rst

.. toctree::
   :hidden:
   :titlesonly:
   :caption: Getting Started:

   installation
   quickstart
   connection

.. toctree::
   :hidden:
   :titlesonly:
   :caption: Guides:

   emulator

.. toctree::
   :hidden:
   :titlesonly:
   :caption: API:

   api/index